@@ -2,7 +2,7 @@ from django.test import TestCase
 
 from chamber.models.humanized_helpers import price_humanized
 
-from germanium.decorators import data_provider  # pylint: disable=E0401
+from germanium.decorators import data_consumer  # pylint: disable=E0401
 from germanium.tools import assert_equal  # pylint: disable=E0401
 
 
@@ -15,6 +15,6 @@ class HumanizedHelpersTestCase(TestCase):
         (None, None, '(None)'),
     )
 
-    @data_provider(numbers_with_currencies)
+    @data_consumer(numbers_with_currencies)
     def test_should_return_price_humanized(self, number, currency, expected):
         assert_equal(expected, price_humanized(number, None, currency))
